"use client";

import { useState, useEffect } from "react";
import { User, Mail } from "lucide-react";
import axios from "axios";

export default function RegistrationForm() {
  const [mounted, setMounted] = useState(false);
  const [formData, setFormData] = useState({
    name: "",
    surname: "",
    phone_prefix: "+61",
    phone_number: "",
    email: "",
    agree_to_be_called: false,
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [submitMessage, setSubmitMessage] = useState("");

  useEffect(() => {
    setMounted(true);
  }, []);

  const handleChange = (
    e: React.ChangeEvent<HTMLInputElement | HTMLSelectElement>,
  ) => {
    const { name, value, type } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]:
        type === "checkbox" ? (e.target as HTMLInputElement).checked : value,
    }));
  };

  const handleSubmit = async (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    setIsSubmitting(true);
    setSubmitMessage("");

    if (formData.name.length < 2 || formData.surname.length < 2) {
      setSubmitMessage(
        "First name and last name must be at least 2 characters long.",
      );
      setIsSubmitting(false);
      return;
    }

    const phoneDigits = formData.phone_number.replace(/\D/g, "");
    if (phoneDigits.length < 6 || phoneDigits.length > 15) {
      setSubmitMessage("Phone number must be between 6 and 15 digits.");
      setIsSubmitting(false);
      return;
    }

    try {
      const response = await axios.post(
        "http://127.0.0.1:8000/api/v1/investors/",
        {
          ...formData,
          phone_number: phoneDigits,
        },
      );

      setSubmitMessage("Registration successful!");
    } catch (error) {
      console.error("Registration error:", error);
      if (axios.isAxiosError(error) && error.response) {
        const responseData = error.response.data;
        if (responseData.detail && Array.isArray(responseData.detail)) {
          const errorMessages = responseData.detail.map(
            (err: { msg: string }) => err.msg,
          );
          setSubmitMessage(errorMessages.join(". "));
        } else {
          setSubmitMessage("Registration failed. Please check your input.");
        }
      } else {
        setSubmitMessage("Registration failed. Please try again later.");
      }
    } finally {
      setIsSubmitting(false);
    }
  };

  if (!mounted) {
    return (
      <div className="space-y-4 w-full max-w-md mx-auto animate-pulse">
        <div className="h-10 bg-gray-700 rounded" />
        <div className="h-10 bg-gray-700 rounded" />
        <div className="h-10 bg-gray-700 rounded" />
        <div className="h-10 bg-gray-700 rounded" />
      </div>
    );
  }

  return (
    <form onSubmit={handleSubmit} className="space-y-4 w-full max-w-md mx-auto">
      <div className="flex flex-col sm:flex-row space-y-4 sm:space-y-0 sm:space-x-4">
        <div className="flex-1">
          <label
            htmlFor="name"
            className="block text-sm font-medium text-gray-300"
          >
            First Name
          </label>
          <div className="mt-1 relative rounded-md shadow-sm">
            <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
              <User className="h-5 w-5 text-gray-400" />
            </div>
            <input
              type="text"
              name="name"
              id="name"
              className="bg-gray-800 text-white focus:ring-purple-500 focus:border-purple-500 block w-full pl-10 py-3 sm:text-sm border-gray-700 rounded-md"
              placeholder="John"
              value={formData.name}
              onChange={handleChange}
              required
              minLength={2}
            />
          </div>
        </div>
        <div className="flex-1">
          <label
            htmlFor="surname"
            className="block text-sm font-medium text-gray-300"
          >
            Last Name
          </label>
          <div className="mt-1 relative rounded-md shadow-sm">
            <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
              <User className="h-5 w-5 text-gray-400" />
            </div>
            <input
              type="text"
              name="surname"
              id="surname"
              className="bg-gray-800 text-white focus:ring-purple-500 focus:border-purple-500 block w-full pl-10 py-3 sm:text-sm border-gray-700 rounded-md"
              placeholder="Doe"
              value={formData.surname}
              onChange={handleChange}
              required
              minLength={2}
            />
          </div>
        </div>
      </div>
      <div>
        <label
          htmlFor="phone_number"
          className="block text-sm font-medium text-gray-300"
        >
          Phone Number
        </label>
        <div className="mt-1 flex rounded-md shadow-sm">
          <span className="inline-flex items-center px-3 rounded-l-md border border-r-0 border-gray-700 bg-gray-800 text-gray-400 sm:text-sm">
            <select
              name="phone_prefix"
              value={formData.phone_prefix}
              onChange={handleChange}
              className="bg-gray-800 text-white border-0 focus:ring-0"
            >
              <option value="+61">+61</option>
              <option value="+1">+1</option>
              <option value="+44">+44</option>
            </select>
          </span>
          <input
            type="tel"
            name="phone_number"
            id="phone_number"
            className="flex-1 min-w-0 block w-full px-3 py-3 rounded-none rounded-r-md bg-gray-800 text-white focus:ring-purple-500 focus:border-purple-500 sm:text-sm border-gray-700"
            placeholder="75243309"
            value={formData.phone_number}
            onChange={handleChange}
            required
            pattern="\d{6,15}"
          />
        </div>
      </div>
      <div>
        <label
          htmlFor="email"
          className="block text-sm font-medium text-gray-300"
        >
          Email
        </label>
        <div className="mt-1 relative rounded-md shadow-sm">
          <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
            <Mail className="h-5 w-5 text-gray-400" />
          </div>
          <input
            type="email"
            name="email"
            id="email"
            className="bg-gray-800 text-white focus:ring-purple-500 focus:border-purple-500 block w-full pl-10 py-3 sm:text-sm border-gray-700 rounded-md"
            placeholder="you@example.com"
            value={formData.email}
            onChange={handleChange}
            required
          />
        </div>
      </div>
      <div className="flex items-center">
        <input
          id="agree_to_be_called"
          name="agree_to_be_called"
          type="checkbox"
          className="h-4 w-4 text-purple-600 focus:ring-purple-500 border-gray-700 rounded"
          checked={formData.agree_to_be_called}
          onChange={handleChange}
        />
        <label
          htmlFor="agree_to_be_called"
          className="ml-2 block text-sm text-gray-300"
        >
          I agree to be contacted about the service
        </label>
      </div>
      <div>
        <button
          type="submit"
          className="w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-purple-600 hover:bg-purple-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-purple-500"
          disabled={isSubmitting}
        >
          {isSubmitting ? "Submitting..." : "Register"}
        </button>
      </div>
      {submitMessage && (
        <p
          className={`text-sm mt-2 ${
            submitMessage.includes("successful")
              ? "text-green-500"
              : "text-red-500"
          }`}
        >
          {submitMessage}
        </p>
      )}
    </form>
  );
}
